# pysustrans

A set of **D**ata **A**nalytics **T**ools in **p**ython

A package that allows performing common statitical analysis on transportation related data.

## Documentation:
Modules documentation can be found on [pysustrans github](https://github.com/rahul-raoniar/pysustrans/blob/main/README.md)

## Installation:
pysustrans can be installed directly using `pip`:
```
pip install pysustrans
```

**Python Require** `Python>=3.8`
**Dependencies:** `numpy`, `pandas`, `scipy`, `matplotlib`, `seaborn`

## Contributions:
Contributions, bugfixes and suggestions are welcomed.
